#!/bin/bash

# ----------------------------------------------------------------------------------
#
# Skin Installer for Ensim Pro for Linux
#
# (c) Copyright 2002-2004 Interjuncture. All rights reserved.
#
# For Ensim related products from Interjuncture, see
# http://www.interjuncture.com/software/ensim/
#
# This script installs a skin into the /usr/lib/opcenter/skins
# folder and then calls applyskin.sh to apply the skin.
#
# ----------------------------------------------------------------------------------

. /etc/rc.d/init.d/functions

function ShowUsage()
{
    if [ $# -lt 2 ]; then
        echo "Usage:     install.sh [skinname]" 
        echo ""
	echo "Example:   ./install.sh Nexus"
	echo ""
	echo "[skinname] is the name of the skin to install; equal to the name"
	echo "           of the subdirectory that came as part of the skin archive"
	echo ""
    fi 
}
function InstallSkin()
{
osmajor=`cut -d '.' -f1 /usr/lib/opcenter/VERSION`
osminor=`cut -d '.' -f2 /usr/lib/opcenter/VERSION`

echo "Installing: $skinname Skin v$skinver"
echo ""
if [ -e $ocw_path/$skinname ]; then
	oldskinver=`cat $ocw_path/$skinname/VERSION`	
	echo "The $skinname Skin v$oldskinver is already installed."
	echo ""
	read -s -n1 -p "Back up the existing version now? [Y]es, (N)o, (Q)uit : " mykey
	case "$mykey" in
	"N" | "n")
		echo "N"
		echo ""
		backup="N"
	;;
	"Q" | "q")
		echo "Q"
		echo ""
		exit
	;;
	* )
		echo "Y"
		echo ""
		backup="Y"
	;;
	esac
	cp -Rf $ocw_path/$skinname $ocw_path/ijbackup
	if [ "$backup" == "Y" ]; then
                oldversion=$( /bin/cat $ocw_path/$skinname/VERSION)
                if [ -e $ocw_path/$skinname.$oldversion ]; then
                        echo "The backup directory, $ocw_path/$skinname.$oldversion, already exists."
                        echo ""
                        echo "Please remove this directory and run install.sh again."
                        exit 1
                fi
                echo -n "Backing up $skinname Skin to $ocw_path/$skinname.$oldversion"
                mv -f $ocw_path/$skinname $ocw_path/$skinname.$oldversion
                success "Backing up $skinname Skin to $ocw_path/$skinname.$oldversion"
                echo ""
	else
		rm -Rf $ocw_path/$skinname
	fi

fi

if [ ! -d $ocw_path ]; then
        echo -n "Creating $ocw_path ..."
        mkdir $ocw_path
	success "Creating $ocw_path ..."
fi
echo -n "Copying $skinname Skin to $ocw_path/$skinname"
cp -Rfu $skinname $ocw_path
chown nobody:nobody $ocw_path/$skinname/config

        if [ -e $ocw_path/ijbackup ]; then
		if [ -e $ocw_path/ijbackup/config ]; then
	                cp -Rf $ocw_path/ijbackup/config $ocw_path/$skinname
	                chown nobody:nobody $ocw_path/$skinname/config/key.php
		fi
                if [ -e $ocw_path/ijbackup/plugins ]; then
                        cp -Rf $ocw_path/ijbackup/plugins $ocw_path/$skinname
                        cp -Rf $ocw_path/ijbackup/httpdconf $ocw_path/$skinname
                fi
        fi

if [ "$osminor" == "7" ]; then
echo "LoadModule php4_module          /usr/lib/httpd/modules/libphp4.so" > /usr/lib/opcenter/skins/$skinname/httpdconf/php
echo "AddType application/x-httpd-php .php .php4 .php3" >> /usr/lib/opcenter/skins/$skinname/httpdconf/php
echo "AddType application/x-httpd-php-source .phps" >> /usr/lib/opcenter/skins/$skinname/httpdconf/php
echo "" >> /usr/lib/opcenter/skins/$skinname/httpdconf/php
echo "php_admin_flag safe_mode off" >> /usr/lib/opcenter/skins/$skinname/httpdconf/php
echo "php_value magic_quotes_gpc off" >> /usr/lib/opcenter/skins/$skinname/httpdconf/php
fi

success "Copying $skinname Skin to $ocw_path/$skinname"
cd $ocw_path/$skinname
echo ""
echo ""

        read -s -n1 -p "Make $skinname Skin the active skin? [Y]es, (N)o : " mykey
        case "$mykey" in
        "N" | "n")
                echo "N"
                echo ""
        ;;
        * )
                echo "Y"
		echo ""
		echo -n "Enabling the $skinname Skin"
		rm -Rf $ocw_path/current
		ln -s $ocw_path/$skinname $ocw_path/current
		success "Enabling the $skinname Skin"
		echo ""
		echo ""
		service webppliance restart
        ;;
	esac

}

level=0
echo "Skin Installer v2.02.11 for Ensim Pro for Linux"
echo "(c) Copyright 2002-2004 Interjuncture.  All rights reserved."
echo "http://www.interjuncture.com/  ~~  support@interjuncture.com"
echo ""
if [ $# -ne 1 ] ; then
    ShowUsage
    exit 1
fi

ocw_path=/usr/lib/opcenter/skins
skinname=$1
skinver=`cat $skinname/VERSION`

InstallSkin
echo ""
echo "$skinname Skin v$skinver installation complete"
echo ""

# FINISH; install.sh v2.02.11 - GAR4 20040130
